/***********************************************************************
MODULE:    Timers
VERSION:   1.00
CONTAINS:  Routines for controlling the timers on the Philips
           P89LPC935
COPYRIGHT: Embedded Systems Academy, Inc. - www.esacademy.com
LICENSE:   May be freely used in commercial and non-commercial code
           without royalties provided this copyright notice remains
           in this file and unaltered
WARNING:   IF THIS FILE IS REGENERATED BY CODE ARCHITECT ANY CHANGES
           MADE WILL BE LOST. WHERE POSSIBLE USE ONLY CODE ARCHITECT
           TO CHANGE THE CONTENTS OF THIS FILE
GENERATED: On "Mar 20 2007" at "10:26:18" by Code Architect 2.12
***********************************************************************/

// SFR description needs to be included
#include <reg935.h>
#include "timer.h"
#include "uart.h"

static int counter;

/***********************************************************************
DESC:    Initializes timers
         Timer 0 generates an interrupt every 10ms
         Timer 1 is not used
RETURNS: Nothing
CAUTION: If interrupts are being used then EA must be set to 1
         after calling this function
************************************************************************/
void timers_init
  (
  void
  )
{
  counter = 0;

  // configure timer 0
  TMOD &= 0xF0;
  TMOD |= 0x01;
  TAMOD &= 0xFE;

  // timer values
  TH0 = 0x70;
  TL0 = 0x00;

  // set timer 0 isr priority to 0
  IP0 &= 0xFD;
  IP0H &= 0xFD;

  // enable timer 0 interrupt
  ET0 = 1;

  // start timer 0
  TR0 = 1;

} // timers_init

/***********************************************************************
DESC:    Timer 0 Interrupt Service Routine
RETURNS: Nothing
CAUTION: timers_init must be called first
         EA must be set to 1
************************************************************************/
void timers_isr0
  (
  void
  ) interrupt 1 using 1
{
  // once per second
  if (++counter >= 100)
  {
    counter = 0;
	uart_transmit('A');
  }

  // reinitialize
  TH0 = 0x70;
  TL0 = 0x00;
} // timers_isr0

/***********************************************************************
DESC:    Starts timer 0
RETURNS: Nothing
CAUTION: timers_init must be called first
************************************************************************/
void timers_starttimer0
  (
  void
  )
{
  TR0 = 1;
} // timers_starttimer0

/***********************************************************************
DESC:    Stops timer 0
RETURNS: Nothing
CAUTION: timers_init must be called first
************************************************************************/
void timers_stoptimer0
  (
  void
  )
{
  TR0 = 0;
} // timers_stoptimer0
